summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libcroco/cr-style.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/libcroco/cr-style.c')
-rw-r--r--src/3rdparty/libcroco/cr-style.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/3rdparty/libcroco/cr-style.c b/src/3rdparty/libcroco/cr-style.c
index ebc669c43..d4dabcfcf 100644
--- a/src/3rdparty/libcroco/cr-style.c
+++ b/src/3rdparty/libcroco/cr-style.c
@@ -982,7 +982,7 @@ set_prop_float (CRStyle * a_style, CRTerm * a_value)
|| !a_value->content.str
|| !a_value->content.str->stryng
|| !a_value->content.str->stryng->str) {
/*unknow type, the float type is set to it's default value */
return CR_OK;
}
@@ -2636,7 +2636,7 @@ cr_style_white_space_type_to_string (enum CRWhiteSpaceType a_code,
str = (gchar *) "inherited";
break;
default:
- str = (gchar *) "unknow white space property value";
+ str = (gchar *) "unknown white space property value";
break;
}
cr_utils_dump_n_chars2 (' ', a_str, a_nb_indent);
@@ -982,7 +982,7 @@ set_prop_float (CRStyle * a_style, CRTerm * a_value)
|| !a_value->content.str->stryng
|| !a_value->content.str->stryng->str) {
- /*unknow type, the float type is set to it's default value */
+ /*unknown type, the float type is set to it's default value */
return CR_OK;
}